
# Slot: usage_slot_name


The name of the slot referenced in the slot_usage

URI: [linkml:usage_slot_name](https://w3id.org/linkml/usage_slot_name)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
